==> placementclient-0.2.0.tar.gz: placementclient-0.2.0/placementclient/client.py <==
#   Licensed under the Apache License, Version 2.0 (the "License"); you may
#   not use this file except in compliance with the License. You may obtain
#   a copy of the License at
#
#        http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#   WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#   License for the specific language governing permissions and limitations
#   under the License.
#

from keystoneauth1 import adapter
from oslo_utils import importutils

from placementclient import exceptions


def Client(version, *args, **kwargs):
    module = 'placementclient.v%s.client' % version
    module = importutils.import_module(module)
    client_class = getattr(module, 'Client')
    return client_class(*args, **kwargs)


class SessionClient(adapter.Adapter):

    client_name = 'python-placementclient'
    client_version = '0.2.0'

    def request(self, url, method, **kwargs):
        kwargs.setdefault('headers', kwargs.get('headers', {}))
        raise_exc = kwargs.pop('raise_exc', True)
        resp = super(SessionClient, self).request(url,
                                                  method,
                                                  raise_exc=False,
                                                  **kwargs)

        if raise_exc and resp.status_code >= 400:
            raise exceptions.from_response(resp, url, method)
        # NOTE(sorrison): Deletes don't return json body
        if resp.status_code == 204:
            return resp, '{}'
        return resp, resp.json()

==> placementclient-1.0.0.tar.gz: placementclient-1.0.0/placementclient/client.py <==
#   Licensed under the Apache License, Version 2.0 (the "License"); you may
#   not use this file except in compliance with the License. You may obtain
#   a copy of the License at
#
#        http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#   WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#   License for the specific language governing permissions and limitations
#   under the License.
#

from keystoneauth1 import adapter
from oslo_utils import importutils

import placementclient
from placementclient import exceptions


def Client(version, *args, **kwargs):
    module = f'placementclient.v{version}.client'
    module = importutils.import_module(module)
    client_class = getattr(module, 'Client')
    return client_class(*args, **kwargs)


class SessionClient(adapter.Adapter):
    client_name = 'python-placementclient'
    client_version = placementclient.__version__

    def request(self, url, method, **kwargs):
        kwargs.setdefault('headers', kwargs.get('headers', {}))
        raise_exc = kwargs.pop('raise_exc', True)
        resp = super().request(url, method, raise_exc=False, **kwargs)

        if raise_exc and resp.status_code >= 400:
            raise exceptions.from_response(resp, url, method)
        # NOTE(sorrison): Deletes don't return json body
        if resp.status_code == 204:
            return resp, '{}'
        return resp, resp.json()
